*********
Changelog
*********

v1.0.2 (2024-10-18)
===================

Changed
-------
- Updated lxml dependency from 5.1.0 to 5.2.1.
- Updated readme to include supported Python version and other textual changes.


v1.0.1 (2024-09-24)
===================
- Upgraded to elementpath==4.5.0
- fixed email address in info blocks.

v1.0.0 (2024-08-23)
===================
First complete version of PySchematron. See the readme for the functionality and limitations.

v0.1.0 (2022-09-10)
===================
First version.
